widgets Package
===============

:mod:`widgets` Package
----------------------

.. automodule:: stoqlib.gui.widgets
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`accounttree` Module
-------------------------

.. automodule:: stoqlib.gui.widgets.accounttree
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`calculator` Module
------------------------

.. automodule:: stoqlib.gui.widgets.calculator
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fieldgrid` Module
-----------------------

.. automodule:: stoqlib.gui.widgets.fieldgrid
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hintedentry` Module
-------------------------

.. automodule:: stoqlib.gui.widgets.hintedentry
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`kanbanview` Module
------------------------

.. automodule:: stoqlib.gui.widgets.kanbanview
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`lazyobjectlist` Module
----------------------------

.. automodule:: stoqlib.gui.widgets.lazyobjectlist
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`notebookbutton` Module
----------------------------

.. automodule:: stoqlib.gui.widgets.notebookbutton
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`processview` Module
-------------------------

.. automodule:: stoqlib.gui.widgets.processview
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`queryentry` Module
------------------------

.. automodule:: stoqlib.gui.widgets.queryentry
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`searchfilterbutton` Module
----------------------------

.. automodule:: stoqlib.gui.widgets.searchfilterbutton
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`searchentry` Module
-------------------------

.. automodule:: stoqlib.gui.widgets.searchentry
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`splash` Module
--------------------

.. automodule:: stoqlib.gui.widgets.splash
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`toolmenuaction` Module
----------------------------

.. automodule:: stoqlib.gui.widgets.toolmenuaction
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`webview` Module
---------------------

.. automodule:: stoqlib.gui.widgets.webview
    :members:
    :undoc-members:
    :show-inheritance:

